@@ -26,6 +26,24 @@ class WhatFuckError(Exception):
 class EmptyResponseError(Exception):
     pass
 
+class MissingEnvironmentVariablesError(Exception):
+    pass
+
+class EnvironmentParseError(Exception):
+    pass
+
+class InvalidTypeError(TypeError):
+    pass
+
+class EmptyToolsError(Exception):
+    pass
+
+class EmptyMessageError(Exception):
+    pass
+
+class EmptyModelError(Exception):
+    pass
+
 class InvalidMessageError(Exception):
     pass
 
@@ -36,11 +54,9 @@ class ParamsRequiredError(ValueError):
     pass
 
 class ForbiddenError(Exception):
-    """Custom exception for 403 Forbidden"""
     pass
 
 class ToolNotFoundError(Exception):
-    """Raised when a base URL for a requested tool cannot be found."""
     pass
 
 class RateLimitError(Exception):
@@ -53,7 +69,6 @@ class AuthenticationError(Exception):
     pass
 
 class InternalServerError(Exception):
-    """Custom exception for 500 Error"""
     pass
 
 class RequiredError(ValueError):
@@ -74,6 +89,42 @@ class InvalidJSONDecodeError(json.decoder.JSONDecodeError):
 class InvalidEmptyError(ValueError):
     pass
 
+class InternalServerMetaLlamaError(Exception):
+    pass
+
+class InternalServerKimiError(Exception):
+    pass
+
+class InternalServerUltimateError(Exception):
+    pass
+
+class InternalServerCohereError(Exception):
+    pass
+
+class InternalServerClaudeError(Exception):
+    pass
+
+class InternalServerGeminiError(Exception):
+    pass
+
+class InternalServerGrokError(Exception):
+    pass
+
+class InternalServerDeepseekError(Exception):
+    pass
+
+class InternalServerOpenaiError(Exception):
+    pass
+
+class InternalServerQwenError(Exception):
+    pass
+
+class InternalServerZaiError(Exception):
+    pass
+
+class InitializeAPIError(Exception):
+    pass
+
 async def AsyncStatusError(resp, status_httpx=False):
     if status_httpx:
         if resp.status_code == 400:
@@ -83,7 +134,7 @@ async def AsyncStatusError(resp, status_httpx=False):
         elif resp.status_code == 402:
             raise ForbiddenError(
                 "Access Forbidden status 402: API Key disabled or invalid. Please upgrade to sk-ryzenth-* format or Different API."
-        )
+            )
         elif resp.status_code == 403:
             raise ForbiddenError(
                 "Access Forbidden status 403: You may be blocked or banned."
@@ -134,6 +185,7 @@ async def AsyncStatusError(resp, status_httpx=False):
             "Status 503: Slow Down or The engine is currently overloaded, please try again later"
         )
 
+
 def SyncStatusError(resp, status_httpx=False):
     if status_httpx:
         if resp.status_code == 400:
@@ -197,8 +249,25 @@ def SyncStatusError(resp, status_httpx=False):
 __all__ = [
     "WhatFuckError",
     "EmptyResponseError",
+    "EmptyMessageError",
+    "EmptyModelError",
+    "EmptyToolsError",
+    "MissingEnvironmentVariablesError",
+    "EnvironmentParseError",
     "ForbiddenError",
     "InternalServerError",
+    "InternalServerMetaLlamaError",
+    "InternalServerKimiError",
+    "InternalServerUltimateError",
+    "InternalServerClaudeError",
+    "InternalServerGeminiError",
+    "InternalServerGrokError",
+    "InternalServerDeepseekError",
+    "InternalServerQwenError",
+    "InternalServerOpenaiError",
+    "InternalServerZaiError",
+    "InitializeAPIError",
+    "InvalidTypeError",
     "AuthenticationError",
     "RateLimitError",
     "ToolNotFoundError",
