@@ -28,7 +28,7 @@ from . import AutoRetry
 
 class WhisperAsync:
     def __init__(self, parent):
-            self.parent = parent
+        self.parent = parent
 
     @Benchmark.performance(level=logging.DEBUG)
     @AutoRetry(max_retries=3, delay=1.5)
@@ -49,7 +49,9 @@ class WhisperAsync:
             )
             await AsyncStatusError(response, status_httpx=True)
             response.raise_for_status()
-            return self.parent.obj(response.json() or {}) if dot_access else response.json()
+            return self.parent.obj(
+                response.json() or {}) if dot_access else response.json()
+
 
 class WhisperSync:
     def __init__(self, parent):
@@ -72,7 +74,10 @@ class WhisperSync:
             )
             SyncStatusError(response, status_httpx=True)
             response.raise_for_status()
-            return self.parent.obj(response.json() or {}) if dot_access else response.json()
+            return self.parent.obj(
+                response.json() or {}) if dot_access else response.json()
         except self.parent.httpx.HTTPError as e:
-            self.parent.logger.error(f"[SYNC] Error fetching from whisper openai {e}")
-            raise WhatFuckError("[SYNC] Error fetching from whisper openai") from e
+            self.parent.logger.error(
+                f"[SYNC] Error fetching from whisper openai {e}")
+            raise WhatFuckError(
+                "[SYNC] Error fetching from whisper openai") from e
